Summary:	Versatile Database Driven Nameserver
Name:		pdns
Version:	3.3.1
%define subrel	2
Release:	%mkrel 1
License:	GPL
Group:		System/Servers
URL:		http://www.powerdns.com/
Source0:	http://downloads.powerdns.com/releases/pdns-%{version}.tar.gz
# https://github.com/PowerDNS/pdns/tree/rel/auth-3.3.1
#Source0:	pdns-%{version}.tar.gz
# wget -rm http://rtfm.powerdns.com
Source1:	rtfm.powerdns.com.tar.bz2
Source2:	pdns.service
# http://blog.powerdns.com/2014/02/06/related-to-recent-dos-attacks-recursor-configuration-file-guidance/
Patch0:		pdns-3.3.1-dos_fix.diff
Requires(post): systemd >= %{systemd_required_version}
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper
BuildRequires:	autoconf automake libtool
BuildRequires:	mysql-devel
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	libstdc++-devel
BuildRequires:	openldap-devel
BuildRequires:	openssl-devel
BuildRequires:	postgresql-devel
BuildRequires:	sqlite3-devel
BuildRequires:	zlib-devel
BuildRequires:	boost-devel
BuildRequires:	lua5.1-devel
BuildRequires:	curl-devel
BuildRequires:	polarssl-devel
#BuildRequires:	ragel asciidoc xmlto <- needed for git snapshots
#BuildRequires:	docbook-utils-pdf
Provides:	nameserver powerdns PowerDNS
Obsoletes:	nameserver powerdns PowerDNS

%description
PowerDNS is a versatile nameserver which supports a large number
of different backends ranging from simple zonefiles to relational
databases and load balancing/failover algorithms.

It comes with support for MySQL, PostgreSQL, Bind zonefiles and the 'pipe
backend' availible as external packages.

%package	backend-pipe
Summary:	Pipe/coprocess backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-pipe
Obsoletes:	PowerDNS-backend-pipe
Requires:	%{name} = %{version}

%description	backend-pipe
This package contains the pipe backend for the PowerDNS nameserver. This
allows PowerDNS to retrieve domain info from a process that accepts
questions on stdin and returns answers on stdout. 

%package	backend-mysql
Summary:	MySQL backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-mysql
Obsoletes:	PowerDNS-backend-mysql
Requires:	%{name} = %{version}

%description	backend-mysql
This package contains a MySQL backend for the PowerDNS nameserver.

%package	backend-pgsql
Summary:	Generic PostgreSQL backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-pgsql
Obsoletes:	PowerDNS-backend-pgsql
Requires:	%{name} = %{version}

%description	backend-pgsql
This package contains a generic PostgreSQL backend 
for the PowerDNS nameserver. It has configurable SQL statements.

%package	backend-ldap
Summary:	LDAP backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-ldap
Obsoletes:	PowerDNS-backend-ldap
Requires:	%{name} = %{version}

%description	backend-ldap
This package contains a LDAP backend for the PowerDNS nameserver.

%package	backend-sqlite
Summary:	SQLite backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-sqlite
Obsoletes:	PowerDNS-backend-sqlite
Requires:	%{name} = %{version}

%description	backend-sqlite
This package contains a SQLite backend for the PowerDNS nameserver.

%package	backend-geo
Summary:	GEO backend for %{name}
Group:		System/Servers
Provides:	PowerDNS-backend-geo
Obsoletes:	PowerDNS-backend-geo
Requires:	%{name} = %{version}

%description	backend-geo
This package contains a geo backend for the PowerDNS nameserver.

%prep
%setup -q -n pdns-%{version} -a1
%patch0 -p1

rm -rf pdns/ext/polarssl*

%build
export CFLAGS="%{optflags} -DLDAP_DEPRECATED -DHAVE_LIBPOLARSSL"
export CXXFLAGS="%{optflags} -DLDAP_DEPRECATED -DHAVE_LIBPOLARSSL"
#autoreconf -fi; automake --add-missing <- needed for git snapshots

%configure2_5x \
    --disable-static \
    --enable-tools \
    --with-sqlite3 \
    --sysconfdir=%{_sysconfdir}/powerdns \
    --libdir=%{_libdir}/powerdns \
    --with-socketdir=/run/powerdns \
    --with-dynmodules="gmysql gpgsql pipe ldap gsqlite3 geo" \
    --with-modules="" \
    --with-mysql-lib=%{_libdir} \
    --with-pgsql-lib=%{_libdir}

%make

%install

%makeinstall_std

install -p -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/pdns.service

find %{buildroot} -name '*.la' -delete

# fix the config
mv %{buildroot}%{_sysconfdir}/powerdns/pdns.conf-dist %{buildroot}%{_sysconfdir}/powerdns/pdns.conf

cat >> %{buildroot}%{_sysconfdir}/powerdns/pdns.conf << EOF
include-dir=%{_sysconfdir}/powerdns/conf.d
module-dir=%{_libdir}/powerdns
socket-dir=/run/powerdns
setuid=powerdns
setgid=powerdns
launch=bind
#recursor=127.0.0.1:5300
EOF

chmod 600 %{buildroot}%{_sysconfdir}/powerdns/pdns.conf

install -d %{buildroot}%{_sysconfdir}/powerdns/conf.d

# fix per backend config files
for i in geo gmysql gpgsql gsqlite3 ldap pipe; do
    echo "# backend config for %{_libdir}/powerdns/lib${i}backend.so" > %{buildroot}%{_sysconfdir}/powerdns/conf.d/lib${i}backend.conf
done

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/powerdns 0755 powerdns powerdns
EOF

%pre
%_pre_useradd powerdns /var/lib/powerdns /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel powerdns

%files
%doc HACKING INSTALL README rtfm.powerdns.com pdns/*.sql
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/pdns.conf
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/pdns.service
%dir %{_sysconfdir}/powerdns
%dir %{_sysconfdir}/powerdns/conf.d
%dir %{_libdir}/powerdns
%{_bindir}/dnsbulktest
# %%{_bindir}/dnsdist <- not here yet
%{_bindir}/dnsreplay
%{_bindir}/dnsscan
%{_bindir}/dnsscope
%{_bindir}/dnstcpbench
%{_bindir}/dnswasher
%{_bindir}/nproxy
%{_bindir}/nsec3dig
%{_bindir}/pdns_control
%{_bindir}/pdnssec
%{_bindir}/zone2json
%{_bindir}/zone2ldap
%{_bindir}/zone2sql
%{_sbindir}/pdns_server
%{_mandir}/man1/dnstcpbench.1*
%{_mandir}/man8/dnsreplay.8*
%{_mandir}/man8/dnsscope.8*
%{_mandir}/man8/dnswasher.8*
%{_mandir}/man8/pdns_control.8*
%{_mandir}/man8/pdnssec.8*
%{_mandir}/man8/pdns_server.8*
%{_mandir}/man8/zone2ldap.8*
%{_mandir}/man8/zone2sql.8*

%files backend-pipe
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libpipebackend.conf
%{_libdir}/powerdns/libpipebackend.so

%files backend-mysql
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libgmysqlbackend.conf
%{_libdir}/powerdns/libgmysqlbackend.so

%files backend-pgsql
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libgpgsqlbackend.conf
%{_libdir}/powerdns/libgpgsqlbackend.so

%files backend-ldap
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libldapbackend.conf
%{_libdir}/powerdns/libldapbackend.so

%files backend-sqlite
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libgsqlite3backend.conf
%{_libdir}/powerdns/libgsqlite3backend.so

%files backend-geo
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/powerdns/conf.d/libgeobackend.conf
%doc modules/geobackend/README
%{_libdir}/powerdns/libgeobackend.so


%changelog
* Thu Jun 12 2014 luigiwalser <luigiwalser> 3.3.1-1.2.mga3
+ Revision: 635801
- add upstream patch to fix DoS issue due to file descriptor consumption

  + oden <oden>
    - fix build
    - official 3.3.1 release
    - fix rpm scripts
    - sync with pdns-3.3.1-1.1.mga4.src.rpm
    - make sure it can be rebuilt against polarssl-1.2.9+
    - sync with cauldron

* Sat May 04 2013 oden <oden> 3.2-4.mga3
+ Revision: 412337
- break out the recursor due to security issues

* Wed Apr 10 2013 malo <malo> 3.2-3.mga3
+ Revision: 409471
- rebuild for boost 1.53

* Sun Mar 24 2013 colin <colin> 3.2-2.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Thu Feb 21 2013 barjac <barjac> 3.2-1.mga3
+ Revision: 399622
- patch for autotools-1.13
- add pdns-recursor.conf to files

  + oden <oden>
    - 3.2
    - merged the pdns-recursor spec file and provide it from this source rpm package
    - fix build for system polarssl libs
    - newer S1
    - various fixes

* Sun Jan 13 2013 luigiwalser <luigiwalser> 3.1-4.mga3
+ Revision: 364974
- add tmpfiles config for /run/powerdns

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 3.1-2.mga3
+ Revision: 333057
- rebuild for new boost

* Thu Nov 15 2012 fwang <fwang> 3.1-1.mga3
+ Revision: 318162
- update install script
- use systemd
- update file list
- build sqlite3 ext
- drop patch
- new version 3.1

* Wed Aug 01 2012 fwang <fwang> 3.0.1-3.mga3
+ Revision: 276898
- build with lua 5.1
- rebuild for new boost

* Wed May 30 2012 fwang <fwang> 3.0.1-2.mga3
+ Revision: 250109
- rebuild for new boost

* Fri Jan 13 2012 fwang <fwang> 3.0.1-1.mga2
+ Revision: 195555
- new version 3.0.1

* Sun Dec 11 2011 fwang <fwang> 3.0-1.mga2
+ Revision: 180569
- drop with lua specification
- br lua
- new version 3.0

* Wed Dec 07 2011 fwang <fwang> 2.9.22-10.mga2
+ Revision: 178113
- drop .la files

* Thu Mar 24 2011 dmorgan <dmorgan> 2.9.22-9.mga1
+ Revision: 77114
- Rebuild against new mysql

* Sun Feb 20 2011 dmorgan <dmorgan> 2.9.22-8.mga1
+ Revision: 54557
- imported package pdns

